@@ -254,7 +254,7 @@ def config(api_key, source, target):
     if not (api_key or source or target):
         print(' Source language:\t' + configs['SOURCE'])
         print(' Target languages:\t' + configs['TARGET'])
-        print(' Yandex API key:\t' + configs['TRANSLATOR_KEY'])
+        print(' Yandex API key:\t' + ' '.join(configs['TRANSLATOR_KEY']))
         exit()
     re.purge
     exit()
